#ifndef NT2_INCLUDE_FUNCTIONS_LINEAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LINEAR_HPP_INCLUDED

#include <nt2/interpol/include/functions/linear.hpp>

#endif
